body, p, div, td {
	font-family: Times;
}

body {
	background-color: #ffffff
}

h1 {
	border-style: solid;
	border-bottom-width: 1px;
	border-top-width: 0px;
	border-left-width: 0px;
	border-right-width: 0px;
	margin-bottom: 0.1em;
}

h2 {
	margin-top: 0em;
	margin-left: 5em;
	margin-bottom: 3em;
	font-size: medium;
	font-style: italic;
	text-align: right;
}

h3 {
	font-style: italic;
	margin-top: 0em;
	margin-bottom: 0.1em;
}

p {
	margin-top: 1em;
	margin-bottom: 0.5em;
}

.chord {
	font-family: Helvetica, Arial;
	font-weight: bold;
	font-size: small;
	font-style: italic;
	color: #000080;
}

.chorus {
	margin-left: 3em;
}

.grids {
	border-style: solid;
	border-width: 1px;
	padding: 1em;
	margin-top: 1em;
	background-color: #fffff8;
}

.timestamp {
	padding-top: 0em;
	font-style: italic;
	font-size: small;
}

